import React from 'react';
import { View } from 'remax/wechat';
import { GridItemProps, GridItemStyle, GridProps } from './data';
import classNames from 'classnames';

const classPrefix = `c-grid`;

const Grid = (props: GridProps) => {
  const { className, style, gap, children } = props;

  const sty: GridProps['style'] & Record<'--columns', string> = {
    '--columns': `${props.columns.toString()}`,
    ...style,
  };

  if (gap !== undefined) {
    sty['--gap'] = gap as string;
  }

  return (
    <View className={classNames(classPrefix, className)} style={sty}>
      {children}
    </View>
  );
};

Grid.defaultProps = {
  gap: 24,
};


const GridItem = (props: GridItemProps) => {
  const { className, style, onClick, children, span = 1 } = props;

  const itemStyle: GridItemStyle = {
    '--item-span': span,
    ...style,
  };

  return (
    <View
      className={classNames(`${classPrefix}-item`, className)}
      style={itemStyle}
      onClick={onClick}
    >
      {children}
    </View>
  );
};

GridItem.defultProps = {
  span: 1,
};

export {
  Grid,
  GridItem,
};
